<script setup>
import { ref, computed, onMounted, onBeforeUnmount } from "vue";
import svgLine from '@/components/svg/svgLine.vue';
import svgDotRect from '@/components/svg/svgDotRect.vue';
import svgText from '@/components/svg/svgText.vue';
import svgSwitch from '@/components/svg/svgSwitch.vue';
import svgImg from '@/components/svg/svgImg.vue';
import svgArc from '@/components/svg/svgArc.vue';
import svgDiode from '@/components/svg/svgDiode.vue';
import svgModule from '@/components/svg/svgModule.vue';
import svgFlow from '@/components/svg/svgFlow.vue';

import imgAcdc from '@/assets/images/img-acdc.png';
import imgBatt from '@/assets/images/img-batt.png';
import imgCharge from '@/assets/images/img-charge.png';
import imgHr from '@/assets/images/img-hr.png';

const lineColor = "#4cb5e2";
const lineColor1 = "#ed973e";
const switchColor = "#f00";
const switchWidth = 40;
const diodeWidth = 20;
const disColor = "#f00";
const charColor = "#0f0";

// 核容放电
const line0 = [
  {
    points: [
      [932, 260],
      [932, 230],
      [1262, 230],
      [1262, 260],
    ],
    roundCornerFlags: [false, false],
    lineColor: disColor
  },
  {
    points: [
      [1262, 390],
      [1262, 420],
      [932, 420],
      [932, 390],
    ],
    roundCornerFlags: [true, false],
    lineColor: disColor
  }
];

// 核容充电
const line1 = [
  {
    points: [
      [682, 79],
      [682, 50],
      [1262, 50],
      [1262, 70],
    ],
    roundCornerFlags: [true, true],
    lineColor: charColor
  },
  {
    points: [
      [1262, 200],
      [1262, 230],
      [932, 230],
      [932, 260],
    ],
    roundCornerFlags: [false, false],
    lineColor: charColor
  },
  {
    points: [
      [932, 390],
      [932, 420],
      [770, 420],
      [770, 359],
    ],
    roundCornerFlags: [false, true],
    lineColor: charColor
  }
];

// 直连充电
const line2 = [
  {
    points: [
      [682, 79],
      [682, 50],
      [932, 50],
      [932, 260],
    ],
    roundCornerFlags: [true, false],
    lineColor: charColor
  },
  {
    points: [
      [932, 390],
      [932, 420],
      [770, 420],
      [770, 359],
    ],
    roundCornerFlags: [false, true],
    lineColor: charColor
  }
];
// 停电放电
const line3 = [
  {
    points: [
      [932, 260],
      [932, 174],
      [1006, 174],
      [1006, 80],
      [932, 80],
      [932, 50],
      [682, 50],
      [682, 79],
    ],
    roundCornerFlags: [false, true, true, false, false, true],
    lineColor: disColor
  },
  {
    points: [
      [770, 359],
      [770, 420],
      [932, 420],
      [932, 390],
    ],
    roundCornerFlags: [true, false],
    lineColor: disColor
  }
];

const state_k1 = ref(true);
const state_k2 = ref(false);
const state_k3 = ref(true);
const currentCabinetIdx = ref(-1);
const currentLockIdx = ref(-1);
const infoVisisble = ref(false);
const left = ref(0);
const top = ref(0);
const settingVisible = ref(false);
const viewInfo = ref({});

const props = defineProps({
  data: {
    type: Object,
    default() { return {}},
  },
  battRt: {
    type: Object,
    default() { return {}},
  },
});

const state = computed(() => {
  return props.data.devWorkstate;
});

const flowList = computed(() => {
  let res = [];
  // 0	直连充电
  // 1	充电测试
  // 2	放电测试
  // 3	停电放电
  // 4	内阻测试

  switch(state.value) {
    // 直连充电
    case 0:
      res = line2;
      break;
    // 核容充电
    case 1:
      res = line1;
      break;
    // 核容放电
    case 2:
      res = line0;
      break;
    // 停电放电
    case 3:
      res = line3;
      break;
    default:
      console.log('state', state.value, '=============');
      break;
  }

  return res;
});

</script>

<template>
  <svg
    v-bind="$attrs"
    width="100%"
    height="100%"
    viewBox="0 0 1350 440"
    xmlns="http://www.w3.org/2000/svg"
    xmlns:xlink="http://www.w3.org/1999/xlink"
    style="position: relative"
  >
    <svg-dot-rect
      :offset="[18, 36]"
      width="720"
      height="384"
      color="#fff"
      fillColor="transparent"
      :rx="8"
      :ry="8"
      :strokeWidth="2"
    ></svg-dot-rect>
    <svg-line
      :points="[
        [58, 130],
        [134, 130],
      ]"
      :color='lineColor'
    ></svg-line>
    <svg-switch
      :offset="[134, 130]"
      :len="switchWidth"
      :color='switchColor'
    ></svg-switch>
    <svg-line
      :points="[
        [174, 130],
        [236, 130],
        [236, 218],
      ]"
      roundCornerFlag
      :color='lineColor'
    ></svg-line>

    <svg-line
      :points="[
        [58, 218],
        [134, 218],
      ]"
      :color='lineColor'
    ></svg-line>
    <svg-switch
      :offset="[134, 218]"
      :len="switchWidth"
      :color='switchColor'
    ></svg-switch>
    <svg-line
      :points="[
        [174, 218],
        [272, 218],
      ]"
      :color='lineColor'
    ></svg-line>
    <svg-dot-rect
      :offset="[252, 124]"
      width="124"
      height="194"
      :color="lineColor"
      fillColor="transparent"
      strokeDasharray="none"
      :rx="8"
      :ry="8"
      :strokeWidth="2"
    ></svg-dot-rect>
    <!-- 32 106 -->
    <svg-line
      :points="[
        [304, 164],
        [272, 164],
        [272, 270],
        [304, 270],
      ]"
      :color='lineColor'
    ></svg-line>
    <svg-switch
      :offset="[304, 164]"
      :len="switchWidth"
      :color='switchColor'
    ></svg-switch>
    <svg-switch
      :offset="[304, 270]"
      :len="switchWidth"
      :color='switchColor'
    ></svg-switch>
    <svg-line
      :points="[
        [344, 164],
        [422, 164],
      ]"
      :color='lineColor'
    ></svg-line>
    <svg-line
      :points="[
        [344, 270],
        [422, 270],
      ]"
      :color='lineColor'
    ></svg-line>
    <!-- 336 -->
    <svg-line
      :points="[
        [422, 50],
        [422, 386],
      ]"
      :color='lineColor'
    ></svg-line>
    <svg-line
      :points="[
        [422, 88],
        [472, 88],
      ]"
      :color='lineColor'
    ></svg-line>
    <svg-line
      :points="[
        [422, 212],
        [472, 212],
      ]"
      :color='lineColor'
    ></svg-line>
    <svg-line
      :points="[
        [422, 350],
        [472, 350],
      ]"
      :color='lineColor'
    ></svg-line>
    <svg-img
      :img="imgAcdc"
      :width="130"
      :height="48"
      :offset="[472, 64]"
    ></svg-img>
    <svg-img
      :img="imgAcdc"
      :width="130"
      :height="48"
      :offset="[472, 188]"
    ></svg-img> 
    <svg-img
      :img="imgAcdc"
      :width="130"
      :height="48"
      :offset="[472, 326]"
    ></svg-img>
    <!-- 18 80 -->
    <svg-line
      :points="[
        [602, 79],
        [682, 79],
      ]"
      :color='lineColor1'
    ></svg-line>
    <!-- 124 -->
    <svg-line
      :points="[
        [602, 203],
        [682, 203],
      ]"
      :color='lineColor1'
    ></svg-line>
    <!-- 262 580 20 -->
    <svg-line
      :points="[
        [602, 341],
        [682, 341],
        [682, 50],
        [1262, 50],
        [1262, 70],
      ]"
      roundCornerFlag
      :color='lineColor1'
    ></svg-line>

    <svg-line
      :points="[
        [602, 97],
        [676, 97],
      ]"
      :color='lineColor'
    ></svg-line>
    <svg-arc
      :offset="[676, 97]"
      r="6"
    ></svg-arc>
    <svg-line
      :points="[
        [688, 97],
        [770, 97],
        [770, 420],
        [1080, 420],
      ]"
      roundCornerFlag
      :color='lineColor'
    ></svg-line>
    <svg-line
      :points="[
        [602, 221],
        [676, 221],
      ]"
      :color='lineColor'
    ></svg-line>
    <svg-arc
      :offset="[676, 221]"
      r="6"
    ></svg-arc>
    <svg-line
      :points="[
        [688, 221],
        [770, 221],
      ]"
      :color='lineColor'
    ></svg-line>
    <svg-line
      :points="[
        [602, 359],
        [770, 359],
      ]"
      :color='lineColor'
    ></svg-line>
    <svg-switch
      :offset="[1080, 420]"
      :len="switchWidth"
      :color='switchColor'
      :state="state_k3"
    ></svg-switch>
    <svg-text
      :offset="[1100, 382]"
      text="K3"
      textAnchor="middle"
    ></svg-text>
    <svg-line
      :points="[
        [1120, 420],
        [1262, 420],
        [1262, 390],
      ]"
      roundCornerFlag
      :color='lineColor'
    ></svg-line>
    <!-- 250 50 -->
    <svg-line
      :points="[
        [932, 50],
        [932, 100],
      ]"
      :color='lineColor1'
    ></svg-line>
    <svg-switch
      :offset="[932, 100]"
      isVertical
      :len="switchWidth"
      :color='switchColor'
      :state="state_k1"
      :turnStart="false"
    ></svg-switch>
    <svg-text
      :offset="[900, 120]"
      text="K1"
      textAnchor="end"
    ></svg-text>
    <svg-text
      :offset="[1026, 120]"
      text="D1"
      textAnchor="start"
    ></svg-text>
    <svg-text
      :offset="[1100, 150]"
      :text="`温度:${data.devTemp}°C`"
      textAnchor="middle"
    ></svg-text>
    <svg-text
      :offset="[918, 240]"
      :text="`${battRt.groupCurr}A`"
      textAnchor="end"
    ></svg-text>
    <svg-line
      :points="[
        [932, 140],
        [932, 260],
      ]"
      :color='lineColor1'
    ></svg-line>
    <svg-line
      :points="[
        [932, 80],
        [1006, 80],
        [1006, 174],
        [932, 174],
      ]"
      roundCornerFlag
      :color='lineColor1'
    ></svg-line>
    <svg-line
      :points="[
        [974, 80],
        [974, 174],
      ]"
      roundCornerFlag
      :color='lineColor1'
    ></svg-line>
    <svg-line
      :points="[
        [932, 390],
        [932, 420],
      ]"
      :color='lineColor'
    ></svg-line>
    <svg-diode
      :offset="[1006, 114]"
      direct="top"
      :len="diodeWidth"
      :color='lineColor1'
    ></svg-diode>
    <svg-diode
      :offset="[974, 114]"
      direct="top"
      :len="diodeWidth"
      :color='lineColor1'
    ></svg-diode>
    <svg-line
      :points="[
        [932, 230],
        [1080, 230],
      ]"
      :color='lineColor1'
    ></svg-line> 
    <svg-line
      :points="[
        [1120, 230],
        [1262, 230],
        [1262, 200],
      ]"
      :color='lineColor1'
    ></svg-line>
    <svg-line
      :points="[
        [1262, 230],
        [1262, 260],
      ]"
      :color='lineColor'
    ></svg-line> 
    <svg-switch
      :offset="[1080, 230]"
      :len="switchWidth"
      :color='switchColor'
      :state="state_k2"
    ></svg-switch>
    <svg-text
      :offset="[1100, 192]"
      text="K2"
      textAnchor="middle"
    ></svg-text>
    <svg-module
      :offset="[865, 260]"
      :img="imgBatt"
      text="电池"
    ></svg-module>
    <svg-module
      :offset="[1197, 70]"
      text="充电模块"
      :img="imgCharge"
    ></svg-module>
    <svg-module
      :offset="[1197, 260]"
      text="核容模块"
      :img="imgHr"
    ></svg-module>
    <!-- 文本 -->
    <svg-text
      :offset="[58, 110]"
      text="防雷"
    ></svg-text>
    <svg-text
      :offset="[58, 236]"
      text="交流输入"
    ></svg-text>
    <svg-text
      :offset="[304, 338]"
      text="ATS"
    ></svg-text>
    <svg-text
      :offset="[422, 398]"
      text="AC220V"
      textAnchor="middle"
    ></svg-text>
    <svg-text
      :offset="[642, 54]"
      text="220V"
      textAnchor="middle"
    ></svg-text>
    <svg-flow
      :lineList="flowList"
    ></svg-flow>
  </svg>
</template>

<style scoped lang="less">

</style>